# Spin orientation of asteroids

This repository contains:
- [fink_spins](fink_spins), a library with necessary routines to work with spin orientation of asteroids
- [data](data/) for various absolute magnitude models + instruction to generate data for notebooks
- [notebooks](notebooks) describing different models, and with various examples and validation steps
